@@ -1,26 +1,21 @@
 from typing import Tuple
-import numpy as np
-import math
 import torch
-from torch import Tensor
 import torch.nn.functional as F
 
 from pyiqa.matlab_utils import fspecial_gauss, imfilter
+from .arch_util import excact_padding_2d
 
 EPS = torch.finfo(torch.float32).eps
 
-def extract_2d_patches(x, kernel, stride=1, dilation=1):
+
+def extract_2d_patches(x, kernel, stride=1, dilation=1, padding='same'):
     """
     Ref: https://stackoverflow.com/a/65886666
     """
-    # Do TF 'SAME' Padding
-    b,c,h,w = x.shape
-    h2 = math.ceil(h / stride)
-    w2 = math.ceil(w / stride)
-    pad_row = (h2 - 1) * stride + (kernel - 1) * dilation + 1 - h
-    pad_col = (w2 - 1) * stride + (kernel - 1) * dilation + 1 - w
-    x = F.pad(x, (pad_col//2, pad_col - pad_col//2, pad_row//2, pad_row - pad_row//2))
-    
+    b, c, h, w = x.shape
+    if padding != 'none':
+        x = excact_padding_2d(x, kernel, stride, dilation, mode=padding)
+
     # Extract patches
     patches = F.unfold(x, kernel, dilation, stride=stride)
     b, _, pnum = patches.shape
@@ -50,18 +45,18 @@ def safe_sqrt(x: torch.Tensor) -> torch.Tensor:
     r"""Safe sqrt with EPS to ensure numeric stability.
 
     Args:
-        x (torch.Tensor): should be non-negative 
+        x (torch.Tensor): should be non-negative
     """
     EPS = torch.finfo(x.dtype).eps
     return torch.sqrt(x + EPS)
 
 
-def normalize_img_with_guass(img: torch.Tensor, 
-                             kernel_size: int = 7, 
-                             sigma: float = 7. / 6, 
+def normalize_img_with_guass(img: torch.Tensor,
+                             kernel_size: int = 7,
+                             sigma: float = 7. / 6,
                              C: int = 1,
                              padding: str = 'same'):
-    
+
     kernel = fspecial_gauss(kernel_size, sigma, 1).to(img)
     mu = imfilter(img, kernel, padding=padding)
     std = imfilter(img**2, kernel, padding=padding)
@@ -92,10 +87,7 @@ def gradient_map(x: torch.Tensor, kernels: torch.Tensor) -> torch.Tensor:
     return safe_sqrt(torch.sum(grads**2, dim=-3, keepdim=True))
 
 
-def similarity_map(map_x: torch.Tensor,
-                   map_y: torch.Tensor,
-                   constant: float,
-                   alpha: float = 0.0) -> torch.Tensor:
+def similarity_map(map_x: torch.Tensor, map_y: torch.Tensor, constant: float, alpha: float = 0.0) -> torch.Tensor:
     r""" Compute similarity_map between two tensors using Dice-like equation.
     Args:
         map_x: Tensor with map to be compared
@@ -141,8 +133,7 @@ def estimate_ggd_param(x: torch.Tensor) -> Tuple[torch.Tensor, torch.Tensor]:
         x (Tensor): shape (b, 1, h, w)
     """
     gamma = torch.arange(0.2, 10 + 0.001, 0.001).to(x)
-    r_table = (torch.lgamma(1. / gamma) + torch.lgamma(3. / gamma) -
-               2 * torch.lgamma(2. / gamma)).exp()
+    r_table = (torch.lgamma(1. / gamma) + torch.lgamma(3. / gamma) - 2 * torch.lgamma(2. / gamma)).exp()
     r_table = r_table.repeat(x.size(0), 1)
 
     sigma_sq = x.pow(2).mean(dim=(-1, -2))
@@ -159,18 +150,16 @@ def estimate_ggd_param(x: torch.Tensor) -> Tuple[torch.Tensor, torch.Tensor]:
     return solution, sigma
 
 
-def estimate_aggd_param(
-        block: torch.Tensor, return_sigma=False) -> Tuple[torch.Tensor, torch.Tensor, torch.Tensor]:
+def estimate_aggd_param(block: torch.Tensor, return_sigma=False) -> Tuple[torch.Tensor, torch.Tensor, torch.Tensor]:
     """Estimate AGGD (Asymmetric Generalized Gaussian Distribution) parameters.
     Args:
         block (Tensor): Image block with shape (b, 1, h, w).
     Returns:
-        Tensor: alpha, beta_l and beta_r for the AGGD distribution 
+        Tensor: alpha, beta_l and beta_r for the AGGD distribution
         (Estimating the parames in Equation 7 in the paper).
     """
     gam = torch.arange(0.2, 10 + 0.001, 0.001).to(block)
-    r_gam = (2 * torch.lgamma(2. / gam) -
-             (torch.lgamma(1. / gam) + torch.lgamma(3. / gam))).exp()
+    r_gam = (2 * torch.lgamma(2. / gam) - (torch.lgamma(1. / gam) + torch.lgamma(3. / gam))).exp()
     r_gam = r_gam.repeat(block.size(0), 1)
 
     mask_left = block < 0
@@ -178,28 +167,19 @@ def estimate_aggd_param(
     count_left = mask_left.sum(dim=(-1, -2), dtype=torch.float32)
     count_right = mask_right.sum(dim=(-1, -2), dtype=torch.float32)
 
-    left_std = safe_sqrt((block * mask_left).pow(2).sum(dim=(-1, -2)) /
-                (count_left + EPS))
-    right_std = safe_sqrt((block * mask_right).pow(2).sum(dim=(-1, -2)) /
-                 (count_right + EPS))
+    left_std = safe_sqrt((block * mask_left).pow(2).sum(dim=(-1, -2)) / (count_left + EPS))
+    right_std = safe_sqrt((block * mask_right).pow(2).sum(dim=(-1, -2)) / (count_right + EPS))
 
     gammahat = left_std / right_std
-    rhat = block.abs().mean(dim=(-1, -2)).pow(2) / block.pow(2).mean(dim=(-1,
-                                                                          -2))
-    rhatnorm = (rhat * (gammahat.pow(3) + 1) *
-                (gammahat + 1)) / (gammahat.pow(2) + 1).pow(2)
+    rhat = block.abs().mean(dim=(-1, -2)).pow(2) / block.pow(2).mean(dim=(-1, -2))
+    rhatnorm = (rhat * (gammahat.pow(3) + 1) * (gammahat + 1)) / (gammahat.pow(2) + 1).pow(2)
     array_position = (r_gam - rhatnorm).abs().argmin(dim=-1)
 
     alpha = gam[array_position]
-    beta_l = left_std.squeeze(-1) * (torch.lgamma(1 / alpha) -
-                                     torch.lgamma(3 / alpha)).exp().sqrt()
-    beta_r = right_std.squeeze(-1) * (torch.lgamma(1 / alpha) -
-                                      torch.lgamma(3 / alpha)).exp().sqrt()
+    beta_l = left_std.squeeze(-1) * (torch.lgamma(1 / alpha) - torch.lgamma(3 / alpha)).exp().sqrt()
+    beta_r = right_std.squeeze(-1) * (torch.lgamma(1 / alpha) - torch.lgamma(3 / alpha)).exp().sqrt()
 
     if return_sigma:
         return alpha, left_std.squeeze(-1), right_std.squeeze(-1)
     else:
         return alpha, beta_l, beta_r
-
-
-
