@@ -43,7 +43,13 @@ class GeneralIQAModel(BaseModel):
             self.cri_mos = build_loss(train_opt['mos_loss_opt']).to(self.device)
         else:
             self.cri_mos = None
-        
+
+        # define metric related loss, such as plcc loss
+        if train_opt.get('metric_loss_opt'):
+            self.cri_metric = build_loss(train_opt['metric_loss_opt']).to(self.device)
+        else:
+            self.cri_metric = None
+
         # set up optimizers and schedulers
         self.setup_optimizers()
         self.setup_schedulers()
@@ -91,7 +97,12 @@ class GeneralIQAModel(BaseModel):
             l_mos = self.cri_mos(self.output_score, self.gt_mos)
             l_total += l_mos
             loss_dict['l_mos'] = l_mos
-        
+
+        if self.cri_metric:
+            l_metric = self.cri_metric(self.output_score, self.gt_mos)
+            l_total += l_metric
+            loss_dict['l_metric'] = l_metric
+
         l_total.backward()
         self.optimizer.step()
 
@@ -148,30 +159,32 @@ class GeneralIQAModel(BaseModel):
         gt_mos = torch.cat(gt_mos, dim=0).squeeze(1).cpu().numpy()
 
         if with_metrics:
-            # calculate all metrics 
+            # calculate all metrics
             for name, opt_ in self.opt['val']['metrics'].items():
                 self.metric_results[name] = calculate_metric([pred_score, gt_mos], opt_)
-            
+
             if self.key_metric is not None:
                 # If the best metric is updated, update and save best model
-                to_update = self._update_best_metric_result(dataset_name, self.key_metric, self.metric_results[self.key_metric], current_iter)
-            
+                to_update = self._update_best_metric_result(dataset_name, self.key_metric,
+                                                            self.metric_results[self.key_metric], current_iter)
+
                 if to_update:
                     for name, opt_ in self.opt['val']['metrics'].items():
                         self._update_metric_result(dataset_name, name, self.metric_results[name], current_iter)
                     self.copy_model(self.net, self.net_best)
                     self.save_network(self.net_best, 'net_best')
             else:
-                # update each metric separately 
+                # update each metric separately
                 updated = []
                 for name, opt_ in self.opt['val']['metrics'].items():
-                    tmp_updated = self._update_best_metric_result(dataset_name, name, self.metric_results[name], current_iter)
+                    tmp_updated = self._update_best_metric_result(dataset_name, name, self.metric_results[name],
+                                                                  current_iter)
                     updated.append(tmp_updated)
-                # save best model if any metric is updated 
-                if sum(updated): 
+                # save best model if any metric is updated
+                if sum(updated):
                     self.copy_model(self.net, self.net_best)
                     self.save_network(self.net_best, 'net_best')
-            
+
             self._log_validation_metric_values(current_iter, dataset_name, tb_logger)
 
     def _log_validation_metric_values(self, current_iter, dataset_name, tb_logger):
@@ -188,7 +201,7 @@ class GeneralIQAModel(BaseModel):
         if tb_logger:
             for metric, value in self.metric_results.items():
                 tb_logger.add_scalar(f'val_metrics/{dataset_name}/{metric}', value, current_iter)
-    
+
     def save(self, epoch, current_iter, save_net_label='net'):
         self.save_network(self.net, save_net_label, current_iter)
         self.save_training_state(epoch, current_iter)
